@@ -1,9 +1,9 @@
 package Unexpected;
 
 use 5.010001;
-use namespace::sweep;
+use namespace::autoclean;
 use overload '""' => sub { $_[ 0 ]->as_string }, fallback => 1;
-use version; our $VERSION = qv( sprintf '0.23.%d', q$Rev: 2 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.24.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moo;
 use Scalar::Util qw( blessed );
@@ -70,7 +70,7 @@ Unexpected - Exception class composed from traits
 
 =head1 Version
 
-This documents version v0.23.$Rev: 2 $ of L<Unexpected>
+This documents version v0.24.$Rev: 1 $ of L<Unexpected>
 
 =head1 Description
 
@@ -114,7 +114,7 @@ error role since overloading is not supported in L<Moo::Role>
 
 =over 3
 
-=item L<namespace::sweep>
+=item L<namespace::autoclean>
 
 =item L<overload>
 
